/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2013 Frederik Heber. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * toCLIString.cpp
 *
 *  Created on: Aug 23, 2013
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "toCLIString.hpp"

#include "Element/element.hpp"
#include "LinearAlgebra/RealSpaceMatrix.hpp"
#include "LinearAlgebra/Vector.hpp"

template <>
const std::string toCLIString( const boost::filesystem::path & _value)
{
  return _value.string();
}

template <>
const std::string toCLIString( const element & _value)
{
  std::stringstream output;
  output << _value.getAtomicNumber();
  return output.str();
}

template <>
const std::string toCLIString( const RealSpaceMatrix& _value)
{
  std::stringstream output;
  output << "\""
    << _value.at(0,0) << ","
    << _value.at(1,0) << ","
    << _value.at(1,1) << ","
    << _value.at(2,0) << ","
    << _value.at(2,1) << ","
    << _value.at(2,2) << "\"";
  return output.str();
}

template <>
const std::string toCLIString( const Vector& _value)
{
  std::stringstream output;
  output << "\"" << _value[0] << "," << _value[1] << "," << _value[2] << "\"";
  return output.str();
}

template <>
const std::string toCLIString( const std::string& _value)
{
  std::stringstream output;
  output << "\"" << _value << "\"";
  return output.str();
}
